package com.ruoyi.szxc.mapper;

import com.ruoyi.szxc.domain.SzxcTaskManage;

import java.util.List;

/**
 * 任务管理Mapper接口
 * 
 * @author hs
 * @date 2024-04-28
 */
public interface SzxcTaskManageMapper 
{
    /**
     * 查询任务管理
     * 
     * @param id 任务管理主键
     * @return 任务管理
     */
    public SzxcTaskManage selectSzxcTaskManageById(Long id);

    /**
     * 查询任务管理列表
     * 
     * @param szxcTaskManage 任务管理
     * @return 任务管理集合
     */
    public List<SzxcTaskManage> selectSzxcTaskManageList(SzxcTaskManage szxcTaskManage);

    /**
     * 新增任务管理
     * 
     * @param szxcTaskManage 任务管理
     * @return 结果
     */
    public int insertSzxcTaskManage(SzxcTaskManage szxcTaskManage);

    /**
     * 修改任务管理
     * 
     * @param szxcTaskManage 任务管理
     * @return 结果
     */
    public int updateSzxcTaskManage(SzxcTaskManage szxcTaskManage);

    /**
     * 删除任务管理
     * 
     * @param id 任务管理主键
     * @return 结果
     */
    public int deleteSzxcTaskManageById(Long id);

    /**
     * 批量删除任务管理
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteSzxcTaskManageByIds(Long[] ids);
}
