package com.ruoyi.szxc.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.szxc.domain.SzxcTaskManage;
import com.ruoyi.szxc.service.ISzxcTaskManageService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 任务管理Controller
 * 
 * @author hs
 * @date 2024-04-28
 */
@RestController
@RequestMapping("/szxc/taskManage")
public class SzxcTaskManageController extends BaseController
{
    @Autowired
    private ISzxcTaskManageService szxcTaskManageService;

    /**
     * 查询任务管理列表
     */
    @PreAuthorize("@ss.hasPermi('szxc:taskManage:list')")
    @GetMapping("/list")
    public TableDataInfo list(SzxcTaskManage szxcTaskManage)
    {
        startPage();
        List<SzxcTaskManage> list = szxcTaskManageService.selectSzxcTaskManageList(szxcTaskManage);
        return getDataTable(list);
    }

    /**
     * 导出任务管理列表
     */
    @PreAuthorize("@ss.hasPermi('szxc:taskManage:export')")
    @Log(title = "任务管理", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, SzxcTaskManage szxcTaskManage)
    {
        List<SzxcTaskManage> list = szxcTaskManageService.selectSzxcTaskManageList(szxcTaskManage);
        ExcelUtil<SzxcTaskManage> util = new ExcelUtil<SzxcTaskManage>(SzxcTaskManage.class);
        util.exportExcel(response, list, "任务管理数据");
    }

    /**
     * 获取任务管理详细信息
     */
    @PreAuthorize("@ss.hasPermi('szxc:taskManage:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(szxcTaskManageService.selectSzxcTaskManageById(id));
    }

    /**
     * 新增任务管理
     */
    @PreAuthorize("@ss.hasPermi('szxc:taskManage:add')")
    @Log(title = "任务管理", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody SzxcTaskManage szxcTaskManage)
    {
        return toAjax(szxcTaskManageService.insertSzxcTaskManage(szxcTaskManage));
    }

    /**
     * 修改任务管理
     */
    @PreAuthorize("@ss.hasPermi('szxc:taskManage:edit')")
    @Log(title = "任务管理", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody SzxcTaskManage szxcTaskManage)
    {
        return toAjax(szxcTaskManageService.updateSzxcTaskManage(szxcTaskManage));
    }

    /**
     * 删除任务管理
     */
    @PreAuthorize("@ss.hasPermi('szxc:taskManage:remove')")
    @Log(title = "任务管理", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(szxcTaskManageService.deleteSzxcTaskManageByIds(ids));
    }
}
